# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global jspspec 2.3
%global major_version 9
%global minor_version 0
%global micro_version 98
%global packdname apache-tomcat-%{version}-src
%global servletspec 4.0
%global elspec 3.0
%global tcuid 53
# Recommended version is specified in java/org/apache/catalina/core/AprLifecycleListener.java
%global native_version 1.2.21


# FHS 2.3 compliant tree structure - http://www.pathname.com/fhs/2.3/
%global basedir %{_var}/lib/%{name}
%global appdir %{basedir}/webapps
%global homedir %{_datadir}/%{name}
%global bindir %{homedir}/bin
%global confdir %{_sysconfdir}/%{name}
%global libdir %{_javadir}/%{name}
%global logdir %{_var}/log/%{name}
%global cachedir %{_var}/cache/%{name}
%global tempdir %{cachedir}/temp
%global workdir %{cachedir}/work
%global _systemddir /lib/systemd/system

Name:          tomcat
Epoch:         1
Version:       %{major_version}.%{minor_version}.%{micro_version}
Release:       %mkrel 1
Summary:       Apache Servlet/JSP Engine, RI for Servlet %{servletspec}/JSP %{jspspec} API
Group:         Development/Java

License:       ASL 2.0
URL:           https://tomcat.apache.org/
Source0:       https://www.apache.org/dist/tomcat/tomcat-%{major_version}/v%{version}/src/%{packdname}.tar.gz
Source1:       %{name}-%{major_version}.%{minor_version}.conf
Source3:       %{name}-%{major_version}.%{minor_version}.sysconfig
Source4:       %{name}-%{major_version}.%{minor_version}.wrapper
Source5:       %{name}-%{major_version}.%{minor_version}.logrotate
Source6:       %{name}-%{major_version}.%{minor_version}-digest.script
Source7:       %{name}-%{major_version}.%{minor_version}-tool-wrapper.script
Source11:      %{name}-%{major_version}.%{minor_version}.service
Source21:      tomcat-functions
Source30:      tomcat-preamble
Source31:      tomcat-server
Source32:      tomcat-named.service
Source33:      java-9-start-up-parameters.conf

Patch0:        %{name}-%{major_version}.%{minor_version}-bootstrap-MANIFEST.MF.patch
Patch1:        %{name}-%{major_version}.%{minor_version}-tomcat-users-webapp.patch
Patch2:        %{name}-build.patch
Patch3:        %{name}-%{major_version}.%{minor_version}-catalina-policy.patch
Patch4:        rhbz-1857043.patch
Patch5:        %{name}-%{major_version}.%{minor_version}-JDTCompiler.patch
Patch6:        %{name}-%{major_version}.%{minor_version}-bnd-annotation.patch

BuildArch:     noarch

BuildRequires: ant
BuildRequires: ecj >= 1:4.10
BuildRequires: findutils
BuildRequires: java-devel >= 1:1.8.0
BuildRequires: javapackages-local
BuildRequires: aqute-bnd
BuildRequires: aqute-bndlib
BuildRequires: systemd

Requires:      java-headless >= 1:1.8.0
Requires:      javapackages-tools
Requires:      %{name}-lib = %{epoch}:%{version}-%{release}
%if 0%{?mageia} || 0%{?fedora} || 0%{?rhel} > 7
Recommends:    tomcat-native >= %{native_version}
%endif
Requires(pre):    shadow-utils
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

# added after log4j sub-package was removed
Provides:         %{name}-log4j = %{epoch}:%{version}-%{release}
# added after jsvc sub-package was removed
Obsoletes:        tomcat-jsvc < 1:9.0.73
Provides:         %{name}-jsvc = %{epoch}:%{version}-%{release}

%description
Tomcat is the servlet container that is used in the official Reference
Implementation for the Java Servlet and JavaServer Pages technologies.
The Java Servlet and JavaServer Pages specifications are developed by
Sun under the Java Community Process.

Tomcat is developed in an open and participatory environment and
released under the Apache Software License version 2.0. Tomcat is intended
to be a collaboration of the best-of-breed developers from around the world.

%package admin-webapps
Summary: The host-manager and manager web applications for Apache Tomcat
Group:         Development/Java
Requires: %{name} = %{epoch}:%{version}-%{release}

%description admin-webapps
The host-manager and manager web applications for Apache Tomcat.

%package docs-webapp
Summary: The docs web application for Apache Tomcat
Group:         Development/Java
Requires: %{name} = %{epoch}:%{version}-%{release}

%description docs-webapp
The docs web application for Apache Tomcat.

%package jsp-%{jspspec}-api
Summary: Apache Tomcat JavaServer Pages v%{jspspec} API Implementation Classes
Group:         Development/Java
Provides: jsp = %{jspspec}
Obsoletes: %{name}-jsp-2.2-api
Requires: %{name}-servlet-%{servletspec}-api = %{epoch}:%{version}-%{release}
Requires: %{name}-el-%{elspec}-api = %{epoch}:%{version}-%{release}

%description jsp-%{jspspec}-api
Apache Tomcat JSP API Implementation Classes.

%package lib
Summary: Libraries needed to run the Tomcat Web container
Group:         Development/Java
Requires: %{name}-jsp-%{jspspec}-api = %{epoch}:%{version}-%{release}
Requires: %{name}-servlet-%{servletspec}-api = %{epoch}:%{version}-%{release}
Requires: %{name}-el-%{elspec}-api = %{epoch}:%{version}-%{release}
Requires: ecj >= 1:4.10
Requires(preun): coreutils

%description lib
Libraries needed to run the Tomcat Web container.

%package servlet-%{servletspec}-api
Summary: Apache Tomcat Java Servlet v%{servletspec} API Implementation Classes
Group:         Development/Java
Provides: servlet = %{servletspec}
Provides: servlet6
Provides: servlet3
Obsoletes: %{name}-servlet-3.1-api

%description servlet-%{servletspec}-api
Apache Tomcat Servlet API Implementation Classes.

%package el-%{elspec}-api
Summary: Apache Tomcat Expression Language v%{elspec} API Implementation Classes
Group:         Development/Java
Provides: el_api = %{elspec}
Obsoletes: %{name}-el-2.2-api

%description el-%{elspec}-api
Apache Tomcat EL API Implementation Classes.

%package webapps
Summary: The ROOT web application for Apache Tomcat
Group:         Development/Java
Requires: %{name} = %{epoch}:%{version}-%{release}

%description webapps
The ROOT web application for Apache Tomcat.

%prep
%setup -q -n %{packdname}
# remove pre-built binaries and windows files
find . -type f \( -name "*.bat" -o -name "*.class" -o -name Thumbs.db -o -name "*.gz" -o \
   -name "*.jar" -o -name "*.war" -o -name "*.zip" \) -delete

%patch -P 0 -p0
%patch -P 1 -p0
%patch -P 2 -p0
%patch -P 3 -p0
%patch -P 4 -p0
%patch -P 5 -p0
%patch -P 6 -p0

# Remove webservices naming resources as it's generally unused
%{__rm} -rf java/org/apache/naming/factory/webservices

# Configure maven files
%mvn_package ":tomcat-el-api" tomcat-el-api
%mvn_alias "org.apache.tomcat:tomcat-el-api" "org.eclipse.jetty.orbit:javax.el"
%mvn_package ":tomcat-jsp-api" tomcat-jsp-api
%mvn_alias "org.apache.tomcat:tomcat-jsp-api" "org.eclipse.jetty.orbit:javax.servlet.jsp"
%mvn_package ":tomcat-servlet-api" tomcat-servlet-api


%build
export OPT_JAR_LIST="xalan-j2-serializer"
# we don't care about the tarballs and we're going to replace
# tomcat-dbcp.jar with apache-commons-{collections,dbcp,pool}-tomcat5.jar
# so just create a dummy file for later removal
touch HACK

# who needs a build.properties file anyway
%{ant} -Dbase.path="." \
  -Dbuild.compiler="modern" \
  -Dcommons-daemon.jar="HACK" \
  -Dcommons-daemon.native.src.tgz="HACK" \
  -Djdt.jar="$(build-classpath ecj/ecj)" \
  -Dtomcat-native.tar.gz="HACK" \
  -Dtomcat-native.home="." \
  -Dcommons-daemon.native.win.mgr.exe="HACK" \
  -Dnsis.exe="HACK" \
  -Djaxrpc-lib.jar="HACK" \
  -Dwsdl4j-lib.jar="HACK" \
  -Dbnd.jar="$(build-classpath aqute-bnd/biz.aQute.bnd)" \
  -Dbnd-annotation.jar="$(build-classpath aqute-bnd/biz.aQute.bnd.annotation)" \
  -Dversion="%{version}" \
  -Dversion.build="%{micro_version}" \
  deploy

# remove some jars that we'll replace with symlinks later
%{__rm} output/build/bin/commons-daemon.jar output/build/lib/ecj.jar
# Remove the example webapps per Apache Tomcat Security Considerations
# see https://tomcat.apache.org/tomcat-9.0-doc/security-howto.html
%{__rm} -rf output/build/webapps/examples


%install
# build initial path structure
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_bindir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_sbindir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_systemddir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{appdir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{bindir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{confdir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{confdir}/Catalina/localhost
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{confdir}/conf.d
/bin/echo "Place your custom *.conf files here. Shell expansion is supported." > ${RPM_BUILD_ROOT}%{confdir}/conf.d/README
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{libdir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{logdir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{_localstatedir}/lib/tomcats
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{homedir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{tempdir}
%{__install} -d -m 0775 ${RPM_BUILD_ROOT}%{workdir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_unitdir}
%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}

# move things into place
# First copy supporting libs to tomcat lib
pushd output/build
    %{__cp} -a bin/*.{jar,xml} ${RPM_BUILD_ROOT}%{bindir}
    %{__cp} -a conf/*.{policy,properties,xml,xsd} ${RPM_BUILD_ROOT}%{confdir}
    %{__cp} -a lib/*.jar ${RPM_BUILD_ROOT}%{libdir}
    %{__cp} -a webapps/* ${RPM_BUILD_ROOT}%{appdir}
popd

%{__sed} -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE1} \
    > ${RPM_BUILD_ROOT}%{confdir}/%{name}.conf
%{__sed} -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE3} \
    > ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 %{SOURCE4} \
    ${RPM_BUILD_ROOT}%{_sbindir}/%{name}
%{__install} -m 0644 %{SOURCE11} \
    ${RPM_BUILD_ROOT}%{_unitdir}/%{name}.service
%{__sed} -e "s|\@\@\@TCLOG\@\@\@|%{logdir}|g" %{SOURCE5} \
    > ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}.disabled
%{__sed} -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE6} \
    > ${RPM_BUILD_ROOT}%{_bindir}/%{name}-digest
%{__sed} -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE7} \
    > ${RPM_BUILD_ROOT}%{_bindir}/%{name}-tool-wrapper

%{__install} -m 0644 %{SOURCE21} \
    ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}/functions
%{__install} -m 0755 %{SOURCE30} \
    ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}/preamble
%{__install} -m 0755 %{SOURCE31} \
    ${RPM_BUILD_ROOT}%{_libexecdir}/%{name}/server
%{__install} -m 0644 %{SOURCE32} \
    ${RPM_BUILD_ROOT}%{_unitdir}/%{name}@.service

%{__install} -m 0644 %{SOURCE33} ${RPM_BUILD_ROOT}%{confdir}/conf.d/

# Substitute libnames in catalina-tasks.xml
sed -i \
   "s,el-api.jar,%{name}-el-%{elspec}-api.jar,;
    s,servlet-api.jar,%{name}-servlet-%{servletspec}-api.jar,;
    s,jsp-api.jar,%{name}-jsp-%{jspspec}-api.jar,;" \
    ${RPM_BUILD_ROOT}%{bindir}/catalina-tasks.xml

# create jsp and servlet API symlinks
pushd ${RPM_BUILD_ROOT}%{_javadir}
   %{__mv} %{name}/jsp-api.jar %{name}-jsp-%{jspspec}-api.jar
   %{__ln_s} %{name}-jsp-%{jspspec}-api.jar %{name}-jsp-api.jar
   %{__mv} %{name}/servlet-api.jar %{name}-servlet-%{servletspec}-api.jar
   %{__ln_s} %{name}-servlet-%{servletspec}-api.jar %{name}-servlet-api.jar
   %{__mv} %{name}/el-api.jar %{name}-el-%{elspec}-api.jar
   %{__ln_s} %{name}-el-%{elspec}-api.jar %{name}-el-api.jar
popd

pushd output/build
    %{_bindir}/build-jar-repository lib ecj 2>&1
popd

pushd ${RPM_BUILD_ROOT}%{libdir}
    # symlink JSP and servlet API jars
    %{__ln_s} ../../java/%{name}-jsp-%{jspspec}-api.jar .
    %{__ln_s} ../../java/%{name}-servlet-%{servletspec}-api.jar .
    %{__ln_s} ../../java/%{name}-el-%{elspec}-api.jar .
    %{__ln_s} $(build-classpath ecj/ecj) jasper-jdt.jar
    
    cp ../../%{name}/bin/tomcat-juli.jar .
popd

# symlink to the FHS locations where we've installed things
pushd ${RPM_BUILD_ROOT}%{homedir}
    %{__ln_s} %{appdir} webapps
    %{__ln_s} %{confdir} conf
    %{__ln_s} %{libdir} lib
    %{__ln_s} %{logdir} logs
    %{__ln_s} %{tempdir} temp
    %{__ln_s} %{workdir} work
popd

# Install the maven metadata for the spec impl artifacts as other projects use them
#%{__install} -d -m 0755 ${RPM_BUILD_ROOT}%{_mavenpomdir}
pushd res/maven
    for pom in *.pom; do
        # fix-up version in all pom files
        sed -i 's/@MAVEN.DEPLOY.VERSION@/%{version}/g' $pom
    done
popd

# Configure and install maven artifacts
%mvn_artifact res/maven/tomcat-el-api.pom output/build/lib/el-api.jar
%mvn_artifact res/maven/tomcat-jsp-api.pom output/build/lib/jsp-api.jar
%mvn_artifact res/maven/tomcat-servlet-api.pom output/build/lib/servlet-api.jar

%mvn_file org.apache.tomcat:tomcat-annotations-api tomcat/annotations-api
%mvn_artifact res/maven/tomcat-annotations-api.pom ${RPM_BUILD_ROOT}%{libdir}/annotations-api.jar
%mvn_artifact res/maven/tomcat-api.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-api.jar
%mvn_file org.apache.tomcat:tomcat-catalina-ant tomcat/catalina-ant
%mvn_artifact res/maven/tomcat-catalina-ant.pom ${RPM_BUILD_ROOT}%{libdir}/catalina-ant.jar
%mvn_file org.apache.tomcat:tomcat-catalina-ha tomcat/catalina-ha
%mvn_artifact res/maven/tomcat-catalina-ha.pom ${RPM_BUILD_ROOT}%{libdir}/catalina-ha.jar
%mvn_file org.apache.tomcat:tomcat-catalina tomcat/catalina
%mvn_artifact res/maven/tomcat-catalina.pom ${RPM_BUILD_ROOT}%{libdir}/catalina.jar
%mvn_artifact res/maven/tomcat-coyote.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-coyote.jar
%mvn_artifact res/maven/tomcat-dbcp.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-dbcp.jar
%mvn_artifact res/maven/tomcat-i18n-cs.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-cs.jar
%mvn_artifact res/maven/tomcat-i18n-de.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-de.jar
%mvn_artifact res/maven/tomcat-i18n-es.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-es.jar
%mvn_artifact res/maven/tomcat-i18n-fr.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-fr.jar
%mvn_artifact res/maven/tomcat-i18n-ja.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-ja.jar
%mvn_artifact res/maven/tomcat-i18n-ko.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-ko.jar
%mvn_artifact res/maven/tomcat-i18n-pt-BR.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-pt-BR.jar
%mvn_artifact res/maven/tomcat-i18n-ru.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-ru.jar
%mvn_artifact res/maven/tomcat-i18n-zh-CN.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-i18n-zh-CN.jar
%mvn_file org.apache.tomcat:tomcat-jasper-el tomcat/jasper-el
%mvn_artifact res/maven/tomcat-jasper-el.pom ${RPM_BUILD_ROOT}%{libdir}/jasper-el.jar
%mvn_file org.apache.tomcat:tomcat-jasper tomcat/jasper
%mvn_artifact res/maven/tomcat-jasper.pom ${RPM_BUILD_ROOT}%{libdir}/jasper.jar
%mvn_file org.apache.tomcat:tomcat-jaspic-api tomcat/jaspic-api
%mvn_artifact res/maven/tomcat-jaspic-api.pom ${RPM_BUILD_ROOT}%{libdir}/jaspic-api.jar
%mvn_artifact res/maven/tomcat-jdbc.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-jdbc.jar
%mvn_artifact res/maven/tomcat-jni.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-jni.jar
%mvn_artifact res/maven/tomcat-juli.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-juli.jar
%mvn_file org.apache.tomcat:tomcat-ssi tomcat/catalina-ssi
%mvn_artifact res/maven/tomcat-ssi.pom ${RPM_BUILD_ROOT}%{libdir}/catalina-ssi.jar
%mvn_file org.apache.tomcat:tomcat-storeconfig tomcat/catalina-storeconfig
%mvn_artifact res/maven/tomcat-storeconfig.pom ${RPM_BUILD_ROOT}%{libdir}/catalina-storeconfig.jar
%mvn_file org.apache.tomcat:tomcat-tribes tomcat/catalina-tribes
%mvn_artifact res/maven/tomcat-tribes.pom ${RPM_BUILD_ROOT}%{libdir}/catalina-tribes.jar
%mvn_artifact res/maven/tomcat-util-scan.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-util-scan.jar
%mvn_artifact res/maven/tomcat-util.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-util.jar
%mvn_file org.apache.tomcat:tomcat-websocket-api tomcat/websocket-api
%mvn_artifact res/maven/tomcat-websocket-api.pom ${RPM_BUILD_ROOT}%{libdir}/websocket-api.jar
%mvn_artifact res/maven/tomcat-websocket.pom ${RPM_BUILD_ROOT}%{libdir}/tomcat-websocket.jar
%mvn_artifact res/maven/tomcat.pom

%mvn_install

%pre
# add the tomcat user and group
getent group tomcat >/dev/null || %{_sbindir}/groupadd -f -g %{tcuid} -r tomcat
if ! getent passwd tomcat >/dev/null ; then
    if ! getent passwd %{tcuid} >/dev/null ; then
        %{_sbindir}/useradd -r -u %{tcuid} -g tomcat -d %{homedir} -s /sbin/nologin -c "Apache Tomcat" tomcat
        # Tomcat uses a reserved ID, so there should never be an else
    fi
fi
exit 0

%post
# install but don't activate
%_post_service %{name}

%post jsp-%{jspspec}-api
%{_sbindir}/update-alternatives --install %{_javadir}/jsp.jar jsp \
    %{_javadir}/%{name}-jsp-%{jspspec}-api.jar 20200

%post servlet-%{servletspec}-api
%{_sbindir}/update-alternatives --install %{_javadir}/servlet.jar servlet \
    %{_javadir}/%{name}-servlet-%{servletspec}-api.jar 30000

%post el-%{elspec}-api
%{_sbindir}/update-alternatives --install %{_javadir}/elspec.jar elspec \
   %{_javadir}/%{name}-el-%{elspec}-api.jar 20300

%preun
# clean tempdir and workdir on removal or upgrade
%{__rm} -rf %{workdir}/* %{tempdir}/*
%_preun_service %{name}

%postun
%systemd_postun_with_restart %{name}.service

%postun jsp-%{jspspec}-api
if [ "$1" = "0" ]; then
    %{_sbindir}/update-alternatives --remove jsp \
        %{_javadir}/%{name}-jsp-%{jspspec}-api.jar
fi

%postun servlet-%{servletspec}-api
if [ "$1" = "0" ]; then
    %{_sbindir}/update-alternatives --remove servlet \
        %{_javadir}/%{name}-servlet-%{servletspec}-api.jar
fi

%postun el-%{elspec}-api
if [ "$1" = "0" ]; then
    %{_sbindir}/update-alternatives --remove elspec \
        %{_javadir}/%{name}-el-%{elspec}-api.jar
fi

%files
%defattr(0664,root,tomcat,0755)
%doc {LICENSE,NOTICE,RELEASE*}
%attr(0755,root,root) %{_bindir}/%{name}-digest
%attr(0755,root,root) %{_bindir}/%{name}-tool-wrapper
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0644,root,root) %{_unitdir}/%{name}.service
%attr(0644,root,root) %{_unitdir}/%{name}@.service
%attr(0755,root,root) %dir %{_libexecdir}/%{name}
%attr(0755,root,root) %dir %{_localstatedir}/lib/tomcats
%attr(0644,root,root) %{_libexecdir}/%{name}/functions
%attr(0755,root,root) %{_libexecdir}/%{name}/preamble
%attr(0755,root,root) %{_libexecdir}/%{name}/server
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}.disabled
%attr(0755,root,tomcat) %dir %{basedir}
%attr(0755,root,tomcat) %dir %{confdir}

%defattr(0664,tomcat,root,0770)
%attr(0770,tomcat,root) %dir %{logdir}

%defattr(0664,root,tomcat,0770)
%attr(0770,root,tomcat) %dir %{cachedir}
%attr(0770,root,tomcat) %dir %{tempdir}
%attr(0770,root,tomcat) %dir %{workdir}

%defattr(0644,root,tomcat,0775)
%attr(0775,root,tomcat) %dir %{appdir}
%attr(0775,root,tomcat) %dir %{confdir}/Catalina
%attr(0775,root,tomcat) %dir %{confdir}/Catalina/localhost
%attr(0755,root,tomcat) %dir %{confdir}/conf.d
%{confdir}/conf.d/README
%{confdir}/conf.d/java-9-start-up-parameters.conf
%config(noreplace) %{confdir}/%{name}.conf
%config(noreplace) %{confdir}/*.policy
%config(noreplace) %{confdir}/*.properties
%config(noreplace) %{confdir}/context.xml
%config(noreplace) %{confdir}/server.xml
%attr(0640,root,tomcat) %config(noreplace) %{confdir}/tomcat-users.xml
%attr(0664,root,tomcat) %{confdir}/tomcat-users.xsd
%attr(0664,root,tomcat) %config(noreplace) %{confdir}/jaspic-providers.xml
%attr(0664,root,tomcat) %{confdir}/jaspic-providers.xsd
%config(noreplace) %{confdir}/web.xml
%dir %{homedir}
%{bindir}/bootstrap.jar
%{bindir}/catalina-tasks.xml
%{homedir}/lib
%{homedir}/temp
%{homedir}/webapps
%{homedir}/work
%{homedir}/logs
%{homedir}/conf

%files admin-webapps
%defattr(0664,root,tomcat,0755)
%{appdir}/host-manager
%{appdir}/manager

%files docs-webapp
%{appdir}/docs

%files lib -f .mfiles
%dir %{libdir}
%{libdir}/*.jar
%{_javadir}/*.jar
%{bindir}/tomcat-juli.jar
%exclude %{libdir}/%{name}-el-%{elspec}-api.jar
%exclude %{libdir}/%{name}-servlet-%{servletspec}*.jar
%exclude %{libdir}/%{name}-jsp-%{jspspec}*.jar
%exclude %{_javadir}/%{name}-servlet-%{servletspec}*.jar
%exclude %{_javadir}/%{name}-el-%{elspec}-api.jar
%exclude %{_javadir}/%{name}-jsp-%{jspspec}*.jar
%exclude %{_javadir}/%{name}-servlet-api.jar
%exclude %{_javadir}/%{name}-el-api.jar
%exclude %{_javadir}/%{name}-jsp-api.jar
%exclude %{_jnidir}/*

%files jsp-%{jspspec}-api -f .mfiles-tomcat-jsp-api
%{_javadir}/%{name}-jsp-%{jspspec}*.jar
%{libdir}/%{name}-jsp-%{jspspec}*.jar
%{_javadir}/%{name}-jsp-api.jar

%files servlet-%{servletspec}-api -f .mfiles-tomcat-servlet-api
%doc LICENSE
%{_javadir}/%{name}-servlet-%{servletspec}*.jar
%{libdir}/%{name}-servlet-%{servletspec}*.jar
%{_javadir}/%{name}-servlet-api.jar

%files el-%{elspec}-api -f .mfiles-tomcat-el-api
%doc LICENSE
%{_javadir}/%{name}-el-%{elspec}-api.jar
%{libdir}/%{name}-el-%{elspec}-api.jar
%{_javadir}/%{name}-el-api.jar

%files webapps
%defattr(0644,tomcat,tomcat,0755)
%{appdir}/ROOT


%changelog
* Thu Dec 19 2024 ns80 <ns80> 1:9.0.98-1.mga9
+ Revision: 2126412
- new version 9.0.98 for CVE-2024-50379 and CVE-2024-54677 (mga#33863)
- new version 9.0.97 for CVE-2024-5231[6-8] (mga#33781)
- new version 9.0.90 for CVE-2024-34750 (mga#33367)
- new version 9.0.87 for CVE-2024-23672 and CVE-2024-24549 (mga#32980)
- new version 9.0.82 for CVE-2023-42795 and CVE-2023-45648 (mga#32377)

* Sun Jun 11 2023 daviddavid <daviddavid> 1:9.0.74-2.mga9
+ Revision: 1961718
- convert to use our systemd service macros

* Tue May 23 2023 ns80 <ns80> 1:9.0.74-1.mga9
+ Revision: 1957843
- new version 9.0.74 for CVE-2023-28709 (mga#31951)

* Wed Apr 05 2023 daviddavid <daviddavid> 1:9.0.73-2.mga9
+ Revision: 1951472
- obsoletes/provides removed jsvc sub-package

* Sun Mar 26 2023 daviddavid <daviddavid> 1:9.0.73-1.mga9
+ Revision: 1950371
- new version: 9.0.73, fixes CVE-2023-28708 (mga#30113)

* Sun Jan 29 2023 daviddavid <daviddavid> 1:9.0.71-1.mga9
+ Revision: 1936886
- Update to 9.0.71
- Remove osgi-annotations patch
- Add bnd-annotation dependency which is in bndlib package

* Fri Jan 13 2023 daviddavid <daviddavid> 1:9.0.70-1.mga9
+ Revision: 1932787
- Update to 9.0.70

* Mon Dec 12 2022 daviddavid <daviddavid> 1:9.0.68-1.mga9
+ Revision: 1920844
- Update to 9.0.68

* Thu Aug 04 2022 neoclust <neoclust> 1:9.0.65-1.mga9
+ Revision: 1875052
- New version 9.0.65
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Oct 17 2021 neoclust <neoclust> 1:9.0.54-1.mga9
+ Revision: 1752008
- New version 9.0.54 (mga#29351)

* Fri Apr 23 2021 daviddavid <daviddavid> 1:9.0.45-1.mga9
+ Revision: 1718024
- Update to 9.0.45

* Wed Mar 24 2021 daviddavid <daviddavid> 1:9.0.44-1.mga9
+ Revision: 1709084
- Update to 9.0.44

* Mon Mar 01 2021 daviddavid <daviddavid> 1:9.0.43-1.mga9
+ Revision: 1694856
- new version: 9.0.43

* Tue Dec 22 2020 daviddavid <daviddavid> 1:9.0.41-1.mga8
+ Revision: 1662811
- new version: 9.0.41

* Sun Dec 06 2020 daviddavid <daviddavid> 1:9.0.40-1.mga8
+ Revision: 1653422
- new version: 9.0.40, fixes CVE-2020-17527 (mga#27739)

* Wed Oct 14 2020 daviddavid <daviddavid> 1:9.0.39-1.mga8
+ Revision: 1635568
- new version: 9.0.39

* Tue Oct 13 2020 daviddavid <daviddavid> 1:9.0.38-1.mga8
+ Revision: 1635253
- new version: 9.0.38 fixes CVE-2020-13943 (mga#27396)

* Thu Aug 13 2020 luigiwalser <luigiwalser> 1:9.0.37-3.mga8
+ Revision: 1613947
- add patch from fedora to fix rhbz#1857043

* Wed Jul 15 2020 daviddavid <daviddavid> 1:9.0.37-2.mga8
+ Revision: 1606330
- new version: 9.0.37, fixes CVE-2020-1393[45] (mga#26862)

* Tue Jul 14 2020 daviddavid <daviddavid> 1:9.0.36-2.mga8
+ Revision: 1606023
- remove unneeded _tmpfilescreate call in %%post (mga#26862#c1)

* Wed Jul 08 2020 daviddavid <daviddavid> 1:9.0.36-1.mga8
+ Revision: 1602914
- new version: 9.0.36, fixes CVE-2020-11996 (mga#26862)

* Fri May 22 2020 neoclust <neoclust> 1:9.0.35-1.mga8
+ Revision: 1586769
- New version 9.0.35 (mga#26657)

* Fri May 01 2020 daviddavid <daviddavid> 1:9.0.34-1.mga8
+ Revision: 1577397
- new version: 9.0.34

* Fri Mar 06 2020 daviddavid <daviddavid> 1:9.0.31-1.mga8
+ Revision: 1554312
- new version: 3.0.31, fixes CVE-2019-17569, CVE-2020-1935, CVE-2020-1938 (mga#26305)

* Wed Feb 19 2020 umeabot <umeabot> 1:9.0.30-2.mga8
+ Revision: 1543549
- Mageia 8 Mass Rebuild

* Tue Jan 21 2020 daviddavid <daviddavid> 1:9.0.30-1.mga8
+ Revision: 1481892
- new version: 9.0.30, fixes CVE-2019-12418 and CVE-2019-17563 (mga#25987)

* Wed Oct 02 2019 daviddavid <daviddavid> 1:9.0.26-1.mga8
+ Revision: 1448725
- new version: 9.0.26
- Resolves: rhbz#1523112 tomcat systemd does not cope with - in service names
- Resolves: rhbz#1510896 Problem to start tomcat with a user whose group has a name different to the user

* Fri Jul 05 2019 daviddavid <daviddavid> 1:9.0.21-1.mga8
+ Revision: 1418726
- new version: 9.0.21 (sync with fc 31)

* Sat Dec 15 2018 daviddavid <daviddavid> 1:9.0.13-1.mga7
+ Revision: 1341345
- new version: 9.0.13, fixes CVE-2018-11784

* Wed Dec 05 2018 daviddavid <daviddavid> 1:9.0.10-1.mga7
+ Revision: 1338423
- new version: 9.0.10 (sync with fc29)
  * CVE-2018-1336 tomcat: A bug in the UTF-8 decoder can lead to DoS
  * CVE-2018-8014 tomcat: Insecure defaults in CORS filter enable 'supportsCredentials' for all origins
  * CVE-2018-8034 tomcat: host name verification missing in WebSocket client
  * CVE-2018-8037 tomcat: Due to a mishandling of close in NIO/NIO2 connectors user sessions     can get mixed up

* Fri Sep 21 2018 umeabot <umeabot> 1:8.0.50-2.mga7
+ Revision: 1291867
- Mageia 7 Mass Rebuild

* Sun Feb 25 2018 daviddavid <daviddavid> 1:8.0.50-1.mga7
+ Revision: 1204886
- new version: 8.0.50, fixes CVE-2018-1304 and CVE-2018-1305 (mga#22644)

* Thu Feb 01 2018 daviddavid <daviddavid> 1:8.0.49-1.mga7
+ Revision: 1198447
- change "zip -u" to "zip"
- resolves: rhbz#1495241 [tomcat] zip -u in spec file causes race condition
- The tomcat-native binary is no longer copied to bin. See http://svn.apache.org/r1818186
- new version: 8.0.49

* Wed Oct 25 2017 daviddavid <daviddavid> 1:8.0.47-1.mga7
+ Revision: 1173763
- new version: 8.0.47, fixes CVE-2017-12615 and CVE-2017-12617 (mga#21933)

* Sun Sep 03 2017 daviddavid <daviddavid> 1:8.0.46-1.mga7
+ Revision: 1150989
- Update to 8.0.46
- Resolves: rhbz#1480620 CVE-2017-7674 tomcat: Cache Poisoning

* Sat Jun 24 2017 daviddavid <daviddavid> 1:8.0.44-1.mga6
+ Revision: 1108269
- Update to 8.0.44, fixes CVE-2017-5664 (mga#21131)

* Fri Apr 21 2017 neoclust <neoclust> 1:8.0.43-1.mga6
+ Revision: 1096991
- New version 8.0.43 ( Fixes CVE-2017-5647 and CVE-2017-5648 )

* Fri Feb 10 2017 daviddavid <daviddavid> 1:8.0.41-1.mga6
+ Revision: 1085490
- Update to 8.0.41, fixes CVE-2016-8745 (mga#20081)

* Thu Dec 01 2016 daviddavid <daviddavid> 1:8.0.39-1.mga6
+ Revision: 1071447
- Update to 8.0.39, fixes CVE-2016-6816 CVE-2016-6817 CVE-2016-8735 (mga#19828)

* Tue Oct 25 2016 daviddavid <daviddavid> 1:8.0.38-1.mga6
+ Revision: 1063493
- Update to 8.0.38

* Mon Oct 24 2016 daviddavid <daviddavid> 1:8.0.37-2.mga6
+ Revision: 1063410
- Resolves: CVE-2016-6325 tomcat: tomcat writable config files allow privilege escalation (mga#19560)
- Resolves: CVE-2016-5425 tomcat: Local privilege escalation via systemd-tmpfiles service (mga#19560)
- move logrotate.d and catalina.out files to -jsvc subpackage (like fedora)

* Fri Sep 09 2016 daviddavid <daviddavid> 1:8.0.37-1.mga6
+ Revision: 1051080
- new version: 8.0.37 fixes CVE-2016-5388 (mga#19306)
- remove merged upstream asfbz-59960 patch

* Fri Aug 12 2016 daviddavid <daviddavid> 1:8.0.36-1.mga6
+ Revision: 1046047
- new version: 8.0.36 (sync with fc24)
  * Resolves: rhbz#1349469 CVE-2016-3092 tomcat: Usage of vulnerable FileUpload package can result in denial of service (updates to 8.0.36)
  * Resolves: rhbz#1364056 The command tomcat-digest doesn't work
  * Resolves: rhbz#1363884 The tomcat-tool-wrapper script is broken
  * Resolves: rhbz#1347864 The systemd service unit does not allow tomcat to shut down gracefully
  * Resolves: rhbz#1347835 The security manager doesn't work correctly (JSPs cannot be compiled)
  * Resolves: rhbz#1341853 rpm -V tomcat fails on /var/log/tomcat/catalina.out
  * Resolves: rhbz#1341850 tomcat-jsvc.service has TOMCAT_USER value hard-coded
  * Resolves: rhbz#1359737 Missing maven depmap for the following artifacts: org.apache.tomcat:tomcat-websocket, org.apache.tomcat:tomcat-websocket-api
  * Resolves: asfbz#59960  Building javadocs with java8 fails
- remove merged upstream patch

* Sat Jul 02 2016 daviddavid <daviddavid> 1:8.0.32-2.mga6
+ Revision: 1038313
- add and rediff patch from debian to fix CVE-2016-3092 (mga#18803)
- sync some changes with fc24
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 daviddavid <daviddavid> 1:8.0.32-1.mga6
+ Revision: 978689
- update to 8.0.32 (sync package tomcat with fedora 24):
  * Fix symlinks from $CATALINA_HOME/lib perspective, resolves: rhbz#1308685
  * Remove log4j support. It has never been working actually. See rhbz#1236297
  * Move shipped config to /etc/sysconfig/tomcat. /etc/tomcat/tomcat.conf can now
    be used to override it with shell expansion, resolves rhbz#1293636
  * Recommend tomcat-native, resolves: rhbz#1243132
  * Resolves: rhbz#1286800 Failed to start component due to wrong
    allowLinking="true" in context.xml
  * Program /bin/nologin does not exist (#1302718)

* Wed Feb 24 2016 neoclust <neoclust> 1:8.0.26-3.mga6
+ Revision: 978602
- First rebuild of the java stack
- sync package tomcat with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Feb 22 2015 luigiwalser <luigiwalser> 0:7.0.59-2.mga5
+ Revision: 816331
- sync with f21

* Sat Feb 14 2015 luigiwalser <luigiwalser> 0:7.0.59-1.mga5
+ Revision: 814932
- 7.0.59 (fixes CVE-2014-0227)

* Sun Jan 11 2015 daviddavid <daviddavid> 0:7.0.54-5.mga5
+ Revision: 809900
- Sync with fc21
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 0:7.0.54-4.mga5
+ Revision: 744471
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:7.0.54-3.mga5
+ Revision: 689916
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 luigiwalser <luigiwalser> 0:7.0.54-2.mga5
+ Revision: 638886
- jsp-api requires el-api (from fedora)

* Thu Jun 12 2014 luigiwalser <luigiwalser> 0:7.0.54-1.mga5
+ Revision: 635821
- 7.0.54 (sync with fedora)
- add patch from apache bug #56373 to fix build with java7
- sync changes from fedora:
  - re-add log4j subpackage with bundled log4j
  - Don't provide maven javax.jsp:jsp-api and
    javax.servlet.jsp:javax.servlet.jsp-api (rhbz#1076949)
  - Drop servlet/el api provides to reduce user machines ending with both

* Sat Mar 29 2014 luigiwalser <luigiwalser> 0:7.0.52-1.mga5
+ Revision: 609693
- sync changes from fedora:
  - Rewrite jsvc implementation, resolves: rhbz#1051743
  - Switch to java-headless R, resolves: rhbz#1068566
  - Create and own %%{_localstatedir}/lib/tomcats, resolves: rhbz#1026741
  - Add pom for tomcat-jdbc, resolves: rhbz#1011003
+ tmb <tmb>
- drop P2 (CVE fix, merged)
- update to 7.0.52 (security fixes)

* Thu Feb 27 2014 tmb <tmb> 0:7.0.47-3.mga5
+ Revision: 597660
- fix tmpfiles tomcat.conf

* Tue Feb 25 2014 luigiwalser <luigiwalser> 0:7.0.47-2.mga5
+ Revision: 597167
- add upstream patch to fix CVE-2014-0050
- fix installation of maven metadata for tomcat-juli.jar (rhbz#1033664)

* Fri Jan 03 2014 dmorgan <dmorgan> 0:7.0.47-1.mga4
+ Revision: 564308
- New version

* Sat Oct 19 2013 umeabot <umeabot> 0:7.0.42-2.mga4
+ Revision: 529812
- Mageia 4 Mass Rebuild

* Fri Jul 12 2013 dmorgan <dmorgan> 0:7.0.42-1.mga4
+ Revision: 453574
- New version

* Tue Jun 25 2013 dmorgan <dmorgan> 0:7.0.41-4.mga4
+ Revision: 446331
- New version

* Sun Mar 24 2013 colin <colin> 0:7.0.34-4.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 20 2013 colin <colin> 0:7.0.34-3.mga3
+ Revision: 390022
- Drop systemv subpackage and tidy up post/preun macros
- Tidy up tmpfiles and don't ship pid file.
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ dmorgan <dmorgan>
- Resolves: rhbz 883806 refix logdir ownership
- Remove non existing script

* Sun Dec 30 2012 oden <oden> 0:7.0.34-1.mga3
+ Revision: 336383
- 7.0.34

* Mon Dec 03 2012 dmorgan <dmorgan> 0:7.0.32-3.mga3
+ Revision: 325905
- Updated to 7.0.32
- Add pidfile as tmpfile
- Use systemd for running as unprivileged user
- Resolves: rhbz 847751 upgrade path was broken

* Sun Jul 01 2012 dmorgan <dmorgan> 0:7.0.27-3.mga3
+ Revision: 266405
- Rebuild to generate mvn() provides

* Sun Jul 01 2012 dmorgan <dmorgan> 0:7.0.27-2.mga3
+ Revision: 266367
- Rebuild to generate mvn() provides

* Fri Jun 22 2012 dmorgan <dmorgan> 0:7.0.27-1.mga3
+ Revision: 262640
- New version 7.0.27
- Allow to build with openjdk 7

* Sat Apr 28 2012 tmb <tmb> 0:7.0.23-4.mga2
+ Revision: 233878
- Require rpm-helper >= 0.24.8-1 for systemd support

* Wed Dec 28 2011 dmorgan <dmorgan> 0:7.0.23-3.mga2
+ Revision: 188453
- Do not use systemd-sysv-convert anymore

* Fri Dec 23 2011 dmorgan <dmorgan> 0:7.0.23-2.mga2
+ Revision: 186239
- Fix groups
- Sync with fedora :
- New version 7.0.23
- Move tomcat-juli.jar to lib package
- Drop %%update_maven_depmap as in tomcat6
- Provide native systemd unit file ported from tomcat6
- New version 7.0.20
- Requires java 1.6.0
- New version tomcat 7.0.19

* Wed Jul 20 2011 dmorgan <dmorgan> 0:7.0.14-4.mga2
+ Revision: 127120
- Remove redhat-lsb requires

* Tue Jul 19 2011 dmorgan <dmorgan> 0:7.0.14-3.mga2
+ Revision: 126632
- Add zip as buildrequire
- imported package tomcat


* Mon Jun 6 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.14-3
- Added initial systemd service
- Fix some paths 

* Sat May 21 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.14-2
- Fixed http source link
- Securify some permissions
- Added licenses for el-api and servlet-api
- Added dependency on jpackage-utils for the javadoc subpackage

* Sat May 14 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.14-1
- Updated to 7.0.14

* Thu May 5 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.12-4
- Provided local paths for libs
- Fixed dependencies
- Fixed update temp/work cleanup

* Mon May 2 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.12-3
- Fixed package groups
- Fixed some permissions
- Fixed some links
- Removed old tomcat6 crap

* Thu Apr 28 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.12-2
- Package now named just tomcat instead of tomcat7
- Removed Provides:  %%{name}-log4j 
- Switched to apache-commons-* names instead of jakarta-commons-* .
- Remove the old changelog 
- BR/R java >= 1:1.6.0 , same for java-devel
- Removed old tomcat6 crap

* Wed Apr 27 2011 Ivan Afonichev <ivan.afonichev@gmail.com> 0:7.0.12-1
- Tomcat7
